Index: plugins/alsa/pcm_roar.c
===================================================================
--- plugins/alsa/pcm_roar.c	(revision 5156)
+++ plugins/alsa/pcm_roar.c	(revision 5157)
@@ -77,5 +77,5 @@
  self->bufptr = 0;
  self->thread_active = 1; // We have to activate the thread before starting it, because the thread lives on that thread_active is 1.
- if ( pthread_create(&(self->thread), NULL, roar_thread, self) < 0 ) {
+ if ( pthread_create(&(self->thread), NULL, roar_plugin_thread, self) < 0 ) {
   self->thread_active = 0;
   return -1;
@@ -85,5 +85,5 @@
 }
 
-void roar_reset(struct roar_alsa_pcm *self) {
+void roar_plugin_reset(struct roar_alsa_pcm *self) {
  if ( !self->stream_opened )
   return;
@@ -120,5 +120,5 @@
  }
 
- roar_reset(self);
+ roar_plugin_reset(self);
 
  return 0;
@@ -240,5 +240,5 @@
  buf = (char *)areas->addr + (areas->first + areas->step * offset) / 8;
 
- ret = roar_write(self, buf, len);
+ ret = roar_plugin_write(self, buf, len);
 
  if ( ret == -1 )
@@ -260,5 +260,5 @@
  // TODO: We need to set *delayp the latency in frames.
  pthread_mutex_lock(&(self->lock));
- roar_drain(self);
+ roar_plugin_drain(self);
  *delayp = snd_pcm_bytes_to_frames(io->pcm, self->bytes_in_buffer);
  pthread_mutex_unlock(&(self->lock));
Index: plugins/alsa/roar.h
===================================================================
--- plugins/alsa/roar.h	(revision 5156)
+++ plugins/alsa/roar.h	(revision 5157)
@@ -76,8 +76,8 @@
 };
 
-void roar_reset(struct roar_alsa_pcm * self);
-void* roar_thread (void * thread_data);
-size_t roar_write(struct roar_alsa_pcm * self, const char * buf, size_t size);
-void roar_drain(struct roar_alsa_pcm * self);
+void roar_plugin_reset(struct roar_alsa_pcm * self);
+void* roar_plugin_thread (void * thread_data);
+size_t roar_plugin_write(struct roar_alsa_pcm * self, const char * buf, size_t size);
+void roar_plugin_drain(struct roar_alsa_pcm * self);
 
 #endif
Index: plugins/alsavs/pcm_roar.c
===================================================================
--- plugins/alsavs/pcm_roar.c	(revision 5156)
+++ plugins/alsavs/pcm_roar.c	(revision 5157)
@@ -77,5 +77,5 @@
  self->bufptr = 0;
  self->thread_active = 1; // We have to activate the thread before starting it, because the thread lives on that thread_active is 1.
- if ( pthread_create(&(self->thread), NULL, roar_thread, self) < 0 ) {
+ if ( pthread_create(&(self->thread), NULL, roar_plugin_thread, self) < 0 ) {
   self->thread_active = 0;
   return -1;
@@ -85,5 +85,5 @@
 }
 
-void roar_reset(struct roar_alsa_pcm *self) {
+void roar_plugin_reset(struct roar_alsa_pcm *self) {
  if ( !self->stream_opened )
   return;
@@ -120,5 +120,5 @@
  }
 
- roar_reset(self);
+ roar_plugin_reset(self);
 
  return 0;
@@ -240,5 +240,5 @@
  buf = (char *)areas->addr + (areas->first + areas->step * offset) / 8;
 
- ret = roar_write(self, buf, len);
+ ret = roar_plugin_write(self, buf, len);
 
  if ( ret == -1 )
@@ -260,5 +260,5 @@
  // TODO: We need to set *delayp the latency in frames.
  pthread_mutex_lock(&(self->lock));
- roar_drain(self);
+ roar_plugin_drain(self);
  *delayp = snd_pcm_bytes_to_frames(io->pcm, self->bytes_in_buffer);
  pthread_mutex_unlock(&(self->lock));
Index: plugins/alsavs/roar.h
===================================================================
--- plugins/alsavs/roar.h	(revision 5156)
+++ plugins/alsavs/roar.h	(revision 5157)
@@ -76,8 +76,8 @@
 };
 
-void roar_reset(struct roar_alsa_pcm * self);
-void* roar_thread (void * thread_data);
-size_t roar_write(struct roar_alsa_pcm * self, const char * buf, size_t size);
-void roar_drain(struct roar_alsa_pcm * self);
+void roar_plugin_reset(struct roar_alsa_pcm * self);
+void* roar_plugin_thread (void * thread_data);
+size_t roar_plugin_write(struct roar_alsa_pcm * self, const char * buf, size_t size);
+void roar_plugin_drain(struct roar_alsa_pcm * self);
 
 #endif
Index: plugins/alsa/thread.c
===================================================================
--- plugins/alsa/thread.c	(revision 5156)
+++ plugins/alsa/thread.c	(revision 5157)
@@ -43,5 +43,5 @@
 
 // Writes to the FIFO buffer. Waits until there is room to write.
-size_t roar_write(struct roar_alsa_pcm *self, const char *buf, size_t size) {
+size_t roar_plugin_write(struct roar_alsa_pcm *self, const char *buf, size_t size) {
  /* Wait until we have a ready buffer */
  while (1) {
@@ -82,6 +82,6 @@
 
 // Attemps to drain the buffer at all times and write to libroar.
-// If there is no data, it will wait for roar_write() to fill up more data.
-void* roar_thread (void * thread_data) {
+// If there is no data, it will wait for roar_plugin_write() to fill up more data.
+void* roar_plugin_thread (void * thread_data) {
  /* We share data between thread and callable functions */
  struct roar_alsa_pcm *self = thread_data;
@@ -109,5 +109,5 @@
    if ( rc < 0 ) {
     _TEST_CANCEL();
-    roar_reset(self);
+    roar_plugin_reset(self);
 
     /* Wakes up a potentially sleeping fill_buffer() */
@@ -135,5 +135,5 @@
    self->bufptr -= rc;
    pthread_mutex_unlock(&(self->lock));
-   ROAR_DBG("roar_thread(*): Wrote data to vio. New bufptr: %i", (int)self->bufptr);
+   ROAR_DBG("roar_plugin_thread(*): Wrote data to vio. New bufptr: %i", (int)self->bufptr);
 
    /* Buffer has decreased, signal fill_buffer() */
@@ -158,5 +158,5 @@
 }
 
-void roar_drain(struct roar_alsa_pcm *self) {
+void roar_plugin_drain(struct roar_alsa_pcm *self) {
  struct timespec now_tv;
  int64_t temp, temp2;
Index: plugins/alsavs/thread.c
===================================================================
--- plugins/alsavs/thread.c	(revision 5156)
+++ plugins/alsavs/thread.c	(revision 5157)
@@ -43,5 +43,5 @@
 
 // Writes to the FIFO buffer. Waits until there is room to write.
-size_t roar_write(struct roar_alsa_pcm *self, const char *buf, size_t size) {
+size_t roar_plugin_write(struct roar_alsa_pcm *self, const char *buf, size_t size) {
  /* Wait until we have a ready buffer */
  while (1) {
@@ -82,6 +82,6 @@
 
 // Attemps to drain the buffer at all times and write to libroar.
-// If there is no data, it will wait for roar_write() to fill up more data.
-void* roar_thread (void * thread_data) {
+// If there is no data, it will wait for roar_plugin_write() to fill up more data.
+void* roar_plugin_thread (void * thread_data) {
  /* We share data between thread and callable functions */
  struct roar_alsa_pcm *self = thread_data;
@@ -109,5 +109,5 @@
    if ( rc < 0 ) {
     _TEST_CANCEL();
-    roar_reset(self);
+    roar_plugin_reset(self);
 
     /* Wakes up a potentially sleeping fill_buffer() */
@@ -135,5 +135,5 @@
    self->bufptr -= rc;
    pthread_mutex_unlock(&(self->lock));
-   ROAR_DBG("roar_thread(*): Wrote data to vio. New bufptr: %i", (int)self->bufptr);
+   ROAR_DBG("roar_plugin_thread(*): Wrote data to vio. New bufptr: %i", (int)self->bufptr);
 
    /* Buffer has decreased, signal fill_buffer() */
@@ -158,5 +158,5 @@
 }
 
-void roar_drain(struct roar_alsa_pcm *self) {
+void roar_plugin_drain(struct roar_alsa_pcm *self) {
  struct timespec now_tv;
  int64_t temp, temp2;
